#!/usr/bin/perl -w

use strict;
$|++;

#
# This is a script from Randal Schwartz (in SysAdmin Mag. Vol 10, Num 4, P41)
# It will take in an email and it if's a multipart/alternative type message
# w/ both text and html parts, it will remove the HTML and make the message
# text only (with a * on the end, indicating HTML was removed)
#
# If the modifications can't/don't need to take place, the message is left
# alone.
#
# I modified the script to use bodyhandle->as_string instead of
# body_as_string since it will handle quoted-printable nicely.
#
# The message is read from STDIN and is printed out to STDOUT.
#
# Typed in by Theo Van Dinter (tvd@{kluge.net,colltech.com})
#
# Run script before email2sms
#
# In .procmailrc, try something like:
#
#  :0 fw
#  * ^Content-type:.*boundary
#  * <100000
#  | usr/sbin/striphtml.pl
#


my $envelope = <STDIN>;

use MIME::Parser;
use MIME::Entity;

my $parser = MIME::Parser->new;

# This will keep temporary and decoded body pieces in memory.
# Make sure that large attachments don't come through here.
#
$parser->output_to_core(1);
$parser->tmp_to_core(1);

my $ent = $parser->parse(\*STDIN);

# Debugging output ...
#$ent->dump_skeleton(\*STDERR); exit 1;

if ( $ent->effective_type eq "multipart/alternative"
	and $ent->parts == 2
	and $ent->parts(0)->effective_type eq "text/plain"
	and $ent->parts(1)->effective_type eq "text/html" ) {
	
	my $newent = MIME::Entity->build(Data =>
		$ent->parts(0)->bodyhandle->as_string .
		" *",
		Encoding => "-SUGGEST",
	);
	$ent->parts([$newent]);
	$ent->make_singlepart;
	$ent->suggest_encoding;
	$ent->sync_headers(Length => 'COMPUTE', Nonstandard => 'ERASE');
}

# Output the message, changed or not.
print $envelope;
$ent->print;
